Hi,
I have about 150 "branches = ..." and "tags = ..." lines in my .git/config file, and I see a 30x improvement in 'git svn rebase -l' when I memoize the cmt_metadata function. (The run time goes down from ~150 seconds to ~5 seconds on my machine).
I see that it was memoized in version: * c1927a8 2006-06-27 | git-svn: several graft-branches improvements
and then removed in version: * 396988e 2007-01-13 | git-svn: get rid of Memoize for now...
Is it safe to re-memoize this function?
Thanks, Lalit Chhabra